summaryrefslogtreecommitdiff
path: root/app/assets/javascripts/lib
diff options
context:
space:
mode:
authorYoginth <me@yoginth.com>2019-05-20 14:11:44 +0000
committerDouglas Barbosa Alexandre <dbalexandre@gmail.com>2019-05-20 14:11:44 +0000
commit2f6a20ce665de6a23fe2c1cc28cc6398afcb1b71 (patch)
tree8d11b78ab29992a7af02aed9dca5289aeb3d21bb /app/assets/javascripts/lib
parent9c1470c260032c8b3d9cd6cf759fd08a610e9a1b (diff)
downloadgitlab-ce-2f6a20ce665de6a23fe2c1cc28cc6398afcb1b71.tar.gz
Fix typos in the whole gitlab-ce project
Diffstat (limited to 'app/assets/javascripts/lib')
-rw-r--r--app/assets/javascripts/lib/utils/highlight.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/app/assets/javascripts/lib/utils/highlight.js b/app/assets/javascripts/lib/utils/highlight.js
index 4f7eff2cca1..8f0afa3467d 100644
--- a/app/assets/javascripts/lib/utils/highlight.js
+++ b/app/assets/javascripts/lib/utils/highlight.js
@@ -27,14 +27,14 @@ export default function highlight(string, match = '', matchPrefix = '<b>', match
const sanitizedValue = sanitize(string.toString(), { allowedTags: [] });
// occurences is an array of character indices that should be
// highlighted in the original string, i.e. [3, 4, 5, 7]
- const occurences = fuzzaldrinPlus.match(sanitizedValue, match.toString());
+ const occurrences = fuzzaldrinPlus.match(sanitizedValue, match.toString());
return sanitizedValue
.split('')
.map((character, i) => {
- if (_.contains(occurences, i)) {
+ if (_.contains(occurrences, i)) {
return `${matchPrefix}${character}${matchSuffix}`;
}
@@ -27,14 +27,14 @@ export default function highlight(string, match = '', matchPrefix = '<b>', match
const sanitizedValue = sanitize(string.toString(), { allowedTags: [] });
- // occurences is an array of character indices that should be
+ // occurrences is an array of character indices that should be
// highlighted in the original string, i.e. [3, 4, 5, 7]